@@ -59,5 +59,5 @@ class ServerApp:
 
         return self.app
 
-    def run(self, host: str = "0.0.0.0", port: int = 8080) -> None:
-        uvicorn.run(self.app, host=host, port=port, log_config=None)
+    def run(self) -> None:
+        uvicorn.run(self.app, host=self.app_config.SERVER_HOST, port=self.app_config.SERVER_PORT, log_config=None)
